@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '1.1005_01';
+our $VERSION = '1.3999_01';
 
 use Carp              ();
 use Fcntl             ();
@@ -30,7 +30,7 @@ our @EXPORT_OK = qw(
     html_builder
 );
 
-my $BYTECODE_VERSION = '1.4';
+my $BYTECODE_VERSION = '1.5';
 
 # $bytecode_version + $fullpath + $compiler_and_parser_options
 my $XSLATE_MAGIC   = qq{xslate;$BYTECODE_VERSION;%s;%s;};
@@ -570,7 +570,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 1.1005_01.
+This document describes Text::Xslate version 1.3999_01.
 
 =head1 SYNOPSIS
 
@@ -726,8 +726,7 @@ template names.
 Specifies a function map which contains name-coderef pairs.
 A function C<f> may be called as C<f($arg)> or C<$arg | f> in templates.
 
-There are built-in functions which are not overridable.
-See L<Text::Xslate::Manual::Builtin> for details.
+There are built-in functions described in L<Text::Xslate::Manual::Builtin>.
 
 =item C<< module => [$module => ?\@import_args, ...] >>
 
@@ -941,13 +940,14 @@ This function is available in templates as the C<uri> filter.
 
 =head3 C<< html_builder { block } | \&function :CodeRef >>
 
-Wraps I<&function> with C<mark_raw> so that the new subroutine returns
-a raw string.
+Wraps a block or I<&function> with C<mark_raw> so that the new subroutine
+will return a raw string.
 
 This function is used to tell the xslate engine that I<&function> is an
 HTML builder that returns HTML sources. For example:
 
     sub some_html_builder {
+        my @args = @_;
         my $html;
         # build HTML ...
         return $html;
